==> huaweicloudsdkiam-3.1.141-py2.py3-none-any.whl: huaweicloudsdkiam/v5/model/show_password_policy_v5_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowPasswordPolicyV5Response(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'password_policy': 'PasswordPolicy'
    }

    attribute_map = {
        'password_policy': 'password_policy'
    }

    def __init__(self, password_policy=None):
        """ShowPasswordPolicyV5Response

        The model defined in huaweicloud sdk

        :param password_policy: 
        :type password_policy: :class:`huaweicloudsdkiam.v5.PasswordPolicy`
        """
        
        super(ShowPasswordPolicyV5Response, self).__init__()

        self._password_policy = None
        self.discriminator = None

        if password_policy is not None:
            self.password_policy = password_policy

    @property
    def password_policy(self):
        """Gets the password_policy of this ShowPasswordPolicyV5Response.

        :return: The password_policy of this ShowPasswordPolicyV5Response.
        :rtype: :class:`huaweicloudsdkiam.v5.PasswordPolicy`
        """
        return self._password_policy

    @password_policy.setter
    def password_policy(self, password_policy):
        """Sets the password_policy of this ShowPasswordPolicyV5Response.

        :param password_policy: The password_policy of this ShowPasswordPolicyV5Response.
        :type password_policy: :class:`huaweicloudsdkiam.v5.PasswordPolicy`
        """
        self._password_policy = password_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowPasswordPolicyV5Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.1.151-py2.py3-none-any.whl: huaweicloudsdkiam/v5/model/show_password_policy_v5_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowPasswordPolicyV5Response(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'password_policy': 'PasswordPolicy'
    }

    attribute_map = {
        'password_policy': 'password_policy'
    }

    def __init__(self, password_policy=None):
        r"""ShowPasswordPolicyV5Response

        The model defined in huaweicloud sdk

        :param password_policy: 
        :type password_policy: :class:`huaweicloudsdkiam.v5.PasswordPolicy`
        """
        
        super(ShowPasswordPolicyV5Response, self).__init__()

        self._password_policy = None
        self.discriminator = None

        if password_policy is not None:
            self.password_policy = password_policy

    @property
    def password_policy(self):
        r"""Gets the password_policy of this ShowPasswordPolicyV5Response.

        :return: The password_policy of this ShowPasswordPolicyV5Response.
        :rtype: :class:`huaweicloudsdkiam.v5.PasswordPolicy`
        """
        return self._password_policy

    @password_policy.setter
    def password_policy(self, password_policy):
        r"""Sets the password_policy of this ShowPasswordPolicyV5Response.

        :param password_policy: The password_policy of this ShowPasswordPolicyV5Response.
        :type password_policy: :class:`huaweicloudsdkiam.v5.PasswordPolicy`
        """
        self._password_policy = password_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowPasswordPolicyV5Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
